@@ -12,32 +12,38 @@ logging.basicConfig(level=logging.DEBUG)
 
 
 @pytest.mark.parametrize(
-    "version, warn",
+    "version, warn, error",
     [
-        ("http://json-schema.org/schema#", True),
-        ("http://json-schema.org/draft-03/schema#", False),
-        ("http://json-schema.org/draft-04/schema#", False),
-        ("http://json-schema.org/draft-06/schema#", True),
-        ("http://json-schema.org/draft-07/schema#", True),
+        ("http://json-schema.org/schema#", True, True),
+        ("http://json-schema.org/draft-03/schema#", False, False),
+        ("http://json-schema.org/draft-04/schema#", False, False),
+        ("http://json-schema.org/draft-06/schema#", True, False),
+        ("http://json-schema.org/draft-07/schema#", True, False),
     ],
 )
-def test_warnings_on_schema_version(version, warn):
+def test_warnings_on_schema_version(version, warn, error):
     schema = {"$schema": version, "$id": "test", "type": "object", "properties": {}}
 
     with warnings.catch_warnings(record=True) as w:
-        pjs.ObjectBuilder(schema)
-
-        if warn:
-            assert len(w) == 1
-            assert "Schema version %s not recognized" % version in str(w[-1].message)
+        try:
+            pjs.ObjectBuilder(schema)
+        except Exception:
+            assert error == True  # noqa
         else:
-            assert len(w) == 0, w[-1].message
+            warn_msgs = [str(m.message) for m in w]
+            present = [
+                "Schema version %s not recognized" % version in msg for msg in warn_msgs
+            ]
+            if warn:
+                assert any(present)
+            else:
+                assert not any(present)
 
 
 def test_schema_validation():
     """Test that the ObjectBuilder validates the schema itself."""
     schema = {
-        "$schema": "http://json-schema.org/schema#",
+        "$schema": "http://json-schema.org/draft-04/schema#",
         "$id": "test",
         "type": "object",
         "properties": {
@@ -52,7 +58,7 @@ def test_schema_validation():
 
 def test_regression_9():
     schema = {
-        "$schema": "http://json-schema.org/schema#",
+        "$schema": "http://json-schema.org/draft-04/schema#",
         "$id": "test",
         "type": "object",
         "properties": {
@@ -67,7 +73,7 @@ def test_regression_9():
 
 def test_build_classes_is_idempotent():
     schema = {
-        "$schema": "http://json-schema.org/schema#",
+        "$schema": "http://json-schema.org/draft-04/schema#",
         "title": "test",
         "type": "object",
         "properties": {
@@ -87,7 +93,7 @@ def test_build_classes_is_idempotent():
 
 def test_underscore_properties():
     schema = {
-        "$schema": "http://json-schema.org/schema#",
+        "$schema": "http://json-schema.org/draft-04/schema#",
         "title": "AggregateQuery",
         "type": "object",
         "properties": {"group": {"type": "object", "properties": {}}},
@@ -108,7 +114,7 @@ def test_underscore_properties():
 
 def test_array_regressions():
     schema = {
-        "$schema": "http://json-schema.org/schema#",
+        "$schema": "http://json-schema.org/draft-04/schema#",
         "$id": "test",
         "type": "object",
         "properties": {
@@ -140,7 +146,7 @@ def test_array_regressions():
 
 def test_arrays_can_have_reffed_items_of_mixed_type():
     schema = {
-        "$schema": "http://json-schema.org/schema#",
+        "$schema": "http://json-schema.org/draft-04/schema#",
         "$id": "test",
         "type": "object",
         "properties": {
@@ -472,7 +478,7 @@ def test_dictionary_transformation(Person, pdict):
 
 def test_strict_mode():
     schema = {
-        "$schema": "http://json-schema.org/schema#",
+        "$schema": "http://json-schema.org/draft-04/schema#",
         "type": "object",
         "properties": {"firstName": {"type": "string"}, "lastName": {"type": "string"}},
         "$id": "test",
@@ -492,7 +498,7 @@ def test_strict_mode():
 
 def test_boolean_in_child_object():
     schema = {
-        "$schema": "http://json-schema.org/schema#",
+        "$schema": "http://json-schema.org/draft-04/schema#",
         "$id": "test",
         "type": "object",
         "properties": {"data": {"type": "object", "additionalProperties": True}},
@@ -514,7 +520,7 @@ def test_boolean_in_child_object():
 def test_default_values(default):
     default = json.loads(default)
     schema = {
-        "$schema": "http://json-schema.org/schema#",
+        "$schema": "http://json-schema.org/draft-04/schema#",
         "$id": "test",
         "type": "object",
         "properties": {"sample": default},
@@ -537,7 +543,7 @@ def test_justareference_example(markdown_examples):
 
 def test_number_multiple_of_validation():
     schema = {
-        "$schema": "http://json-schema.org/schema#",
+        "$schema": "http://json-schema.org/draft-04/schema#",
         "$id": "test",
         "type": "object",
         "title": "Base",
